@@ -1,6 +1,9 @@
+from .bet import Bet
+from .game import Game
 from .user import User
 from .poll import Poll
 from .wallet import Wallet
+from .user_seed import UserSeed
 from .collection import Collection
 from .user_wallet import UserWallet
 from .daily_claim import DailyClaim
